@@ -14,7 +14,7 @@ class RandomizerData:
                  logic: Logic = Logic.COMPLETABLE, statues: str = "4", enemizer: Enemizer = Enemizer.NONE,
                  start_location: StartLocation = StartLocation.SOUTH_CAPE, firebird: bool = False, ohko: bool = False,
                  red_jewel_madness: bool = False, allow_glitches: bool = False, boss_shuffle: bool = False,
-                 open_mode: bool = False, overworld_shuffle: bool = False, dungeon_shuffle: bool = False):
+                 open_mode: bool = False, z3: bool = False, overworld_shuffle: bool = False, dungeon_shuffle: bool = False):
         self.seed = seed
         self.difficulty = difficulty
 #        self.level = level
@@ -31,3 +31,4 @@ class RandomizerData:
         self.overworld_shuffle = overworld_shuffle
         self.dungeon_shuffle = dungeon_shuffle
         self.open_mode = open_mode
+        self.z3 = z3
